@@ -56,9 +56,9 @@ class WorxCloud(dict):
         cloud: CloudType.WORX
         | CloudType.KRESS
         | CloudType.LANDXCAPE
-        | CloudType.FERREX
         | str = CloudType.WORX,
         verify_ssl: bool = True,
+        tz: str | None = None,  # pylint: disable=invalid-name
     ) -> None:
         """
         Initialize :class:WorxCloud class and set default attribute values.
@@ -106,7 +106,7 @@ class WorxCloud(dict):
         Args:
             username (str): Email used for logging into the app for your device.
             password (str): Password for your account.
-            cloud (CloudType.WORX | CloudType.KRESS | CloudType.LANDXCAPE | CloudType.FERREX | str, optional): The CloudType matching your device. Defaults to CloudType.WORX.
+            cloud (CloudType.WORX | CloudType.KRESS | CloudType.LANDXCAPE | str, optional): The CloudType matching your device. Defaults to CloudType.WORX.
             index (int, optional): Device number if more than one is connected to your account (starting from 0 representing the first added device). Defaults to 0.
             verify_ssl (bool, optional): Should this module verify the API endpoint SSL certificate? Defaults to True.
 
@@ -119,16 +119,15 @@ class WorxCloud(dict):
             cloud,
             (
                 type(CloudType.WORX),
-                type(CloudType.KRESS),
                 type(CloudType.LANDXCAPE),
-                type(CloudType.FERREX),
+                type(CloudType.KRESS),
             ),
         ):
             try:
                 cloud = getattr(CloudType, cloud.upper())
             except AttributeError:
                 raise TypeError(
-                    "Wrong type specified, valid types are: worx, landxcape, kress, ferrex"
+                    "Wrong type specified, valid types are: worx, landxcape or kress"
                 )
 
         self._api = LandroidCloudAPI(username, password, cloud)
@@ -138,6 +137,7 @@ class WorxCloud(dict):
         self._auth_result = False
         self._log = get_logger("pyworxcloud")
         self._raw = None
+        self._tz = tz
 
         self._save_zones = None
         self._verify_ssl = verify_ssl
@@ -203,10 +203,7 @@ class WorxCloud(dict):
     def disconnect(self) -> None:
         """Close API connections."""
         if self.mqtt.connected:
-            # topic = self.mqtt.topics["out"]
-            # self.mqtt.unsubscribe(topic)
             self.mqtt.disconnect()
-            # self.mqtt.loop_stop()
 
     def connect(
         self,
@@ -285,7 +282,6 @@ class WorxCloud(dict):
         self._log.debug("MQTT loop started")
 
         # Convert time strings to objects.
-
         self._log.debug("Converting date and time string")
         for name, device in self.devices.items():
             convert_to_time(
@@ -305,7 +301,11 @@ class WorxCloud(dict):
         auth_data = self._api.auth()
 
         try:
-            self._api.set_token(auth_data["access_token"])
+            self._api.set_token(
+                auth_data["access_token"],
+                auth_data["expires_in"],
+                auth_data["refresh_token"],
+            )
             self._api.set_token_type(auth_data["token_type"])
 
             self._api.get_profile()
@@ -437,13 +437,6 @@ class WorxCloud(dict):
                 # Map current zone to zone index
                 device.zone.current = device.zone.indicies[device.zone.index]
 
-                # Map next zone to zone index
-                device.zone.next = (
-                    device.zone.indicies[device.zone.index + 1]
-                    if device.zone.index < 9
-                    else 0
-                )
-
             # Fetch main schedule
             if "sc" in data["cfg"]:
                 if "ots" in data["cfg"]["sc"]:
@@ -551,7 +544,11 @@ class WorxCloud(dict):
                         "end"
                     ] = end_time.time().strftime("%H:%M")
 
-            device.schedules.update_progress_and_next()
+            device.schedules.update_progress_and_next(
+                tz=self._tz
+                if not isinstance(self._tz, type(None))
+                else device.time_zone
+            )
 
         convert_to_time(
             device.name, device, device.time_zone, callback=self.update_attribute
