@@ -2,10 +2,7 @@
 # pylint: disable=unnecessary-lambda
 from __future__ import annotations
 
-import functools
 import json
-import operator
-import re
 import time
 import uuid
 from typing import Any
@@ -36,43 +33,44 @@ class LandroidCloudAPI:
         self,
         username: str,
         password: str,
-        cloud: CloudType.WORX
-        | CloudType.KRESS
-        | CloudType.LANDXCAPE
-        | CloudType.FERREX = CloudType.WORX,
+        cloud: CloudType.WORX | CloudType.KRESS | CloudType.LANDXCAPE,
+        tz: str | None = None,  # pylint: disable=invalid-name
     ) -> None:
         """Initialize a new instance of the API broker.
 
         Args:
             username (str): Email for the user account.
             password (str): Password for the user account.
-            cloud (CloudType.WORX | CloudType.KRESS | CloudType.LANDXCAPE | CloudType.FERREX, optional): CloudType representing the device. Defaults to CloudType.WORX.
+            cloud (CloudType.WORX | CloudType.KRESS | CloudType.LANDXCAPE , optional): CloudType representing the device. Defaults to CloudType.WORX.
         """
         self.cloud: CloudType = cloud
         self._token_type = "app"
-        self._token = None
-        self._tokenrefresh = 0
+        self._access_token = None
+        self._refresh_token = None
+        self._token_expire = 0
         self.uuid = None
         self._api_host = None
         self._data = None
+        self._tz = tz
 
         self.api_url = cloud.URL
         self.api_key = cloud.KEY
+        self.token_url = cloud.TOKEN_URL
         self.username = username
         self.password = password
 
-    def set_token(self, token: str, now: int = -1) -> None:
+    def set_token(self, access_token: str, expires_in: int, refresh_token: str) -> None:
         """Set the API token to be used
 
         Args:
-            token (str): Token from authentication.
-            now (int, optional): When was the token last refreshed. Defaults to -1 which will force a token refresh.
+            access_token (str): Token from authentication.
+            expires_in (int): Seconds to token expire.
+            refresh_token (str): Token to use when refreshing access_token
         """
-        if now == -1:
-            now = int(time.time())
-
-        self._tokenrefresh = now
-        self._token = token
+        now = int(time.time())
+        self._token_expire = now + expires_in
+        self._access_token = access_token
+        self._refresh_token = refresh_token
 
     def set_token_type(self, token_type: str) -> None:
         """Set token type.
@@ -82,39 +80,18 @@ class LandroidCloudAPI:
         """
         self._token_type = token_type
 
-    def _generate_identify_token(self, seed_token: str) -> str:
-        """Generate identify token."""
-        text_to_char = [ord(c) for c in self.api_url]
-
-        step_one = re.findall(r".{1,2}", seed_token)
-        step_two = list(map((lambda hex: int(hex, 16)), step_one))
-
-        step_three = list(
-            map(
-                (
-                    lambda foo: functools.reduce(
-                        (lambda x, y: operator.xor(x, y)),
-                        text_to_char,
-                        foo,
-                    )
-                ),
-                step_two,
-            )
-        )
-        step_four = list(map(chr, step_three))
-
-        final = "".join(step_four)
-        return final
-
-    def _get_headers(self) -> dict:
+    def _get_headers(self, tokenheaders: bool = False) -> dict:
         """Create header object for communication packets."""
         header_data = {}
-        header_data["Content-Type"] = "application/json"
-        header_data["Authorization"] = self._token_type + " " + self._token
+        if tokenheaders:
+            header_data["Content-Type"] = "application/x-www-form-urlencoded"
+        else:
+            header_data["Content-Type"] = "application/json"
+            header_data["Authorization"] = self._token_type + " " + self._access_token
 
         return header_data
 
-    def auth(self) -> str:
+    def auth(self, refresh: bool = False) -> str:
         """Authenticate against API endpoint
 
         Returns:
@@ -123,20 +100,19 @@ class LandroidCloudAPI:
         self.uuid = str(uuid.uuid1())
         self._api_host = (API_BASE).format(self.api_url)
 
-        self._token = self._generate_identify_token(self.api_key)
-
         payload_data = {}
-        payload_data["username"] = self.username
-        payload_data["password"] = self.password
+        if not refresh:
+            payload_data["username"] = self.username
+            payload_data["password"] = self.password
+        else:
+            payload_data["refresh_token"] = self._refresh_token
         payload_data["grant_type"] = "password"
-        payload_data["client_id"] = 1
-        payload_data["type"] = "app"
-        payload_data["client_secret"] = self._token
+        payload_data["client_id"] = self.api_key
         payload_data["scope"] = "*"
 
-        payload = json.dumps(payload_data)
-
-        calldata = self._call("/oauth/token", payload, checktoken=False)
+        calldata = self._call(
+            "/oauth/token", payload=payload_data, checktoken=False, generatetoken=True
+        )
 
         return calldata
 
@@ -185,64 +161,67 @@ class LandroidCloudAPI:
         except:
             return None
 
-    def get_board(self, board_id: int) -> list:
-        """Get board info and features for a given baseboard.
-
-        Args:
-            board_code (str): Board_id to get information for.
-
-        Returns:
-            list | None: A list of attributes with board information.
-        """
-        boards = self._call("/boards")
-        try:
-            return [x for x in boards if x["id"] == board_id][0]
-        except:
-            return None
-
-    def get_status(self, serial: str) -> str:
+    def get_status(self, serial: str) -> str | bool:
         """Get device status
 
         Args:
             serial (str): Serialnumber for the device to get status for.
 
         Returns:
-            str: JSON object containing the device status.
+            str: JSON object containing the device status if found.
+            bool: Returns false if no device was found.
         """
-        callstr = f"/product-items/{serial}/status"
+        callstr = f"/product-items?status=1"
         calldata = self._call(callstr)
-        return calldata
+
+        for mower in calldata:
+            if mower["serial_number"] == serial:
+                return json.dumps(mower, indent=4)
+
+        return False
 
     def _call(
-        self, path: str, payload: str | None = None, checktoken: bool = True
+        self,
+        path: str | None = None,
+        payload: str | None = None,
+        checktoken: bool = True,
+        generatetoken: bool = False,
+        post: bool = False,
     ) -> str:
         """Do the actual call to the device."""
         # Check if token needs refreshing
         now = int(time.time())  # Current time in unix timestamp format
-        if checktoken and ((self._tokenrefresh + 3000) < now):
+        if checktoken and ((self._token_expire - 300) < now):
             try:
                 auth_data = self.auth()
 
                 if "return_code" in auth_data:
                     return
 
-                self.set_token(auth_data["access_token"], now)
+                self.set_token(
+                    auth_data["access_token"],
+                    auth_data["expires_in"],
+                    auth_data["refresh_token"],
+                )
                 self.set_token_type(auth_data["token_type"])
             except Exception as ex:  # pylint: disable=bare-except
                 raise TokenError("Error refreshing authentication token") from ex
 
         try:
-            if payload:
+            url = (
+                (self._api_host + path)
+                if not generatetoken
+                else ("https://" + self.token_url + path)
+            )
+            if payload or post:
                 req = requests.post(
-                    self._api_host + path,
+                    url,
                     data=payload,
-                    headers=self._get_headers(),
+                    headers=self._get_headers(generatetoken),
                     timeout=30,
                 )
             else:
-                req = requests.get(
-                    self._api_host + path, headers=self._get_headers(), timeout=30
-                )
+                req = requests.get(url, headers=self._get_headers(), timeout=30)
 
             req.raise_for_status()
         except requests.exceptions.HTTPError as err:
