@@ -1,11 +1,8 @@
 """Device capabilities."""
 from __future__ import annotations
 
-import logging
 from enum import IntEnum
 
-from ..events import EventHandler, LandroidEvent
-
 
 class DeviceCapability(IntEnum):
     """Available device capabilities."""
