@@ -29,10 +29,13 @@ class DeviceHandler(LDict, Actions):
     __raw_data: str = None
     __json_data: str = None
 
-    def __init__(self, api: Any = None, product: Any = None) -> dict:
+    def __init__(
+        self, api: Any = None, product: Any = None, tz: str | None = None
+    ) -> dict:
         """Initialize the object."""
         super().__init__()
 
+        self._tz = tz
         if not isinstance(product, type(None)) and not isinstance(api, type(None)):
             self.__mapinfo(api, product)
 
@@ -83,7 +86,6 @@ class DeviceHandler(LDict, Actions):
         self.battery = Battery(data)
         self.blades = Blades(data)
         self.chassis = ProductInfo(InfoType.MOWER, api, data["product_id"])
-        self.mainboard = ProductInfo(InfoType.BOARD, api, self.chassis.board_id)
         self.error = States(StateType.ERROR)
         self.orientation = Orientation([0, 0, 0])
         self.capabilities = Capability()
@@ -93,6 +95,8 @@ class DeviceHandler(LDict, Actions):
         self.warranty = Warranty(data)
         self.firmware = Firmware(data)
         self.schedules = Schedule()
+        self.in_topic = data["mqtt_topics"]["command_in"]
+        self.out_topic = data["mqtt_topics"]["command_out"]
 
         if data in ["lawn_perimeter", "lawn_size"]:
             self.lawn = Lawn(data["lawn_perimeter"], data["lawn_size"])
