@@ -137,15 +137,11 @@ class MQTT(mqtt.Client, LDict):
         self.queue = MQTTQueue()
         self.topics = {}
         for name, device in devices.items():
-            topic_in = MQTT_IN.format(device.mainboard.code, device.mac_address)
-            topic_out = MQTT_OUT.format(device.mainboard.code, device.mac_address)
-            self.topics.update({name: MQTTTopics(topic_in, topic_out)})
+            self.topics.update({name: MQTTTopics(device.in_topic, device.out_topic)})
 
-        # try:
-        #     self.__loop = asyncio.get_event_loop()
-        #     self.__loop.run_in_executor(None, self.__handle_queue)
-        # except RuntimeError:
-        #     return
+    def set_topics(self, name: str, commandIn: str, commandOut: str) -> None:
+        """Set the MQTT topics."""
+        self.topics.update({name: MQTTTopics(commandIn, commandOut)})
 
     def set_eventloop(self, eventloop: Any) -> None:
         """Set eventloop to be used ny queue handler."""
